@@ -51,6 +51,7 @@ class Request extends import_channelOwner.ChannelOwner {
     this._redirectedTo = null;
     this._failureText = null;
     this._fallbackOverrides = {};
+    this._hasResponse = false;
     this._redirectedFrom = Request.fromNullable(initializer.redirectedFrom);
     if (this._redirectedFrom)
       this._redirectedFrom._redirectedTo = this;
@@ -66,6 +67,8 @@ class Request extends import_channelOwner.ChannelOwner {
       responseStart: -1,
       responseEnd: -1
     };
+    this._hasResponse = this._initializer.hasResponse;
+    this._channel.on("response", () => this._hasResponse = true);
   }
   static from(request) {
     return request._object;
