@@ -221,6 +221,7 @@ ${text}`;
       postData
     };
     this.emit(APIRequestContext.Events.Request, requestEvent);
+    let destroyRequest;
     const resultPromise = new Promise((fulfill, reject) => {
       const requestConstructor = (url.protocol === "https:" ? import_https.default : import_http.default).request;
       const agent = options.agent || (url.protocol === "https:" ? import_happyEyeballs.httpsHappyEyeballsAgent : import_happyEyeballs.httpHappyEyeballsAgent);
@@ -379,7 +380,7 @@ ${text}`;
         body.on("end", notifyBodyFinished);
       });
       request.on("error", reject);
-      progress.cleanupWhenAborted(() => request.destroy());
+      destroyRequest = () => request.destroy();
       listeners.push(
         import_utils.eventsHelper.addEventListener(this, APIRequestContext.Events.Dispose, () => {
           reject(new Error("Request context disposed."));
@@ -431,7 +432,10 @@ ${text}`;
         request.write(postData);
       request.end();
     });
-    return progress.race(resultPromise);
+    return progress.race(resultPromise).catch((error) => {
+      destroyRequest?.();
+      throw error;
+    });
   }
   _getHttpCredentials(url) {
     if (!this._defaultOptions().httpCredentials?.origin || url.origin.toLowerCase() === this._defaultOptions().httpCredentials?.origin?.toLowerCase())
