@@ -165,7 +165,7 @@ class HarTracer {
   _onAPIRequest(event) {
     if (!this._shouldIncludeEntryWithUrl(event.url.toString()))
       return;
-    const harEntry = createHarEntry(event.method, event.url, void 0, this._options);
+    const harEntry = createHarEntry(void 0, event.method, event.url, void 0, this._options);
     harEntry._apiRequest = true;
     if (!this._options.omitCookies)
       harEntry.request.cookies = event.cookies;
@@ -227,9 +227,7 @@ class HarTracer {
     if (!url)
       return;
     const pageEntry = this._createPageEntryIfNeeded(page);
-    const harEntry = createHarEntry(request.method(), url, request.frame()?.guid, this._options);
-    if (pageEntry)
-      harEntry.pageref = pageEntry.id;
+    const harEntry = createHarEntry(pageEntry?.id, request.method(), url, request.frame()?.guid, this._options);
     this._recordRequestHeadersAndCookies(harEntry, request.headers());
     harEntry.request.postData = this._postDataForRequest(request, this._options.content);
     if (!this._options.omitSizes)
@@ -522,10 +520,9 @@ class HarTracer {
     return result;
   }
 }
-function createHarEntry(method, url, frameref, options) {
+function createHarEntry(pageRef, method, url, frameref, options) {
   const harEntry = {
-    _frameref: options.includeTraceInfo ? frameref : void 0,
-    _monotonicTime: options.includeTraceInfo ? (0, import_utils.monotonicTime)() : void 0,
+    pageref: pageRef,
     startedDateTime: (/* @__PURE__ */ new Date()).toISOString(),
     time: -1,
     request: {
@@ -558,7 +555,9 @@ function createHarEntry(method, url, frameref, options) {
       send: -1,
       wait: -1,
       receive: -1
-    }
+    },
+    _frameref: options.includeTraceInfo ? frameref : void 0,
+    _monotonicTime: options.includeTraceInfo ? (0, import_utils.monotonicTime)() : void 0
   };
   return harEntry;
 }
