@@ -121,6 +121,11 @@ class Request extends import_instrumentation.SdkObject {
     this._updateHeadersMap();
     this._isFavicon = url.endsWith("/favicon.ico") || !!redirectedFrom?._isFavicon;
   }
+  static {
+    this.Events = {
+      Response: "response"
+    };
+  }
   _setFailureText(failureText) {
     this._failureText = failureText;
     this._waitForResponsePromise.resolve(null);
@@ -172,6 +177,7 @@ class Request extends import_instrumentation.SdkObject {
   _setResponse(response) {
     this._response = response;
     this._waitForResponsePromise.resolve(response);
+    this.emit(Request.Events.Response, response);
   }
   _finalRequest() {
     return this._redirectedTo ? this._redirectedTo._finalRequest() : this;
@@ -264,6 +270,8 @@ class Route extends import_instrumentation.SdkObject {
         body = "";
         isBase64 = false;
       }
+    } else if (!overrides.status || overrides.status < 200 || overrides.status >= 400) {
+      this._request._responseBodyOverride = { body, isBase64 };
     }
     const headers = [...overrides.headers || []];
     this._maybeAddCorsHeaders(headers);
@@ -416,6 +424,10 @@ class Response extends import_instrumentation.SdkObject {
       this._contentPromise = this._finishedPromise.then(async () => {
         if (this._status >= 300 && this._status <= 399)
           throw new Error("Response body is unavailable for redirect responses");
+        if (this._request._responseBodyOverride) {
+          const { body, isBase64 } = this._request._responseBodyOverride;
+          return Buffer.from(body, isBase64 ? "base64" : "utf-8");
+        }
         return this._getResponseBodyCallback();
       });
     }
