@@ -166,20 +166,20 @@ class Screenshotter {
       progress.log("taking page screenshot");
       const viewportSize = await this._originalViewportSize(progress);
       await this._preparePageForScreenshot(progress, this._page.mainFrame(), options.style, options.caret !== "initial", options.animations === "disabled");
-      if (options.fullPage) {
-        const fullPageSize = await this._fullPageSize(progress);
-        let documentRect = { x: 0, y: 0, width: fullPageSize.width, height: fullPageSize.height };
-        const fitsViewport = fullPageSize.width <= viewportSize.width && fullPageSize.height <= viewportSize.height;
-        if (options.clip)
-          documentRect = trimClipToSize(options.clip, documentRect);
-        const buffer2 = await this._screenshot(progress, format, documentRect, void 0, fitsViewport, options);
+      try {
+        if (options.fullPage) {
+          const fullPageSize = await this._fullPageSize(progress);
+          let documentRect = { x: 0, y: 0, width: fullPageSize.width, height: fullPageSize.height };
+          const fitsViewport = fullPageSize.width <= viewportSize.width && fullPageSize.height <= viewportSize.height;
+          if (options.clip)
+            documentRect = trimClipToSize(options.clip, documentRect);
+          return await this._screenshot(progress, format, documentRect, void 0, fitsViewport, options);
+        }
+        const viewportRect = options.clip ? trimClipToSize(options.clip, viewportSize) : { x: 0, y: 0, ...viewportSize };
+        return await this._screenshot(progress, format, void 0, viewportRect, true, options);
+      } finally {
         await this._restorePageAfterScreenshot();
-        return buffer2;
       }
-      const viewportRect = options.clip ? trimClipToSize(options.clip, viewportSize) : { x: 0, y: 0, ...viewportSize };
-      const buffer = await this._screenshot(progress, format, void 0, viewportRect, true, options);
-      await this._restorePageAfterScreenshot();
-      return buffer;
     });
   }
   async screenshotElement(progress, handle, options) {
@@ -188,36 +188,42 @@ class Screenshotter {
       progress.log("taking element screenshot");
       const viewportSize = await this._originalViewportSize(progress);
       await this._preparePageForScreenshot(progress, handle._frame, options.style, options.caret !== "initial", options.animations === "disabled");
-      await handle._waitAndScrollIntoViewIfNeeded(
-        progress,
-        true
-        /* waitForVisible */
-      );
-      const boundingBox = await progress.race(handle.boundingBox());
-      (0, import_utils.assert)(boundingBox, "Node is either not visible or not an HTMLElement");
-      (0, import_utils.assert)(boundingBox.width !== 0, "Node has 0 width.");
-      (0, import_utils.assert)(boundingBox.height !== 0, "Node has 0 height.");
-      const fitsViewport = boundingBox.width <= viewportSize.width && boundingBox.height <= viewportSize.height;
-      const scrollOffset = await this._page.mainFrame().waitForFunctionValueInUtility(progress, () => ({ x: window.scrollX, y: window.scrollY }));
-      const documentRect = { ...boundingBox };
-      documentRect.x += scrollOffset.x;
-      documentRect.y += scrollOffset.y;
-      const buffer = await this._screenshot(progress, format, import_helper.helper.enclosingIntRect(documentRect), void 0, fitsViewport, options);
-      await this._restorePageAfterScreenshot();
-      return buffer;
+      try {
+        await handle._waitAndScrollIntoViewIfNeeded(
+          progress,
+          true
+          /* waitForVisible */
+        );
+        const boundingBox = await progress.race(handle.boundingBox());
+        (0, import_utils.assert)(boundingBox, "Node is either not visible or not an HTMLElement");
+        (0, import_utils.assert)(boundingBox.width !== 0, "Node has 0 width.");
+        (0, import_utils.assert)(boundingBox.height !== 0, "Node has 0 height.");
+        const fitsViewport = boundingBox.width <= viewportSize.width && boundingBox.height <= viewportSize.height;
+        const scrollOffset = await this._page.mainFrame().waitForFunctionValueInUtility(progress, () => ({ x: window.scrollX, y: window.scrollY }));
+        const documentRect = { ...boundingBox };
+        documentRect.x += scrollOffset.x;
+        documentRect.y += scrollOffset.y;
+        return await this._screenshot(progress, format, import_helper.helper.enclosingIntRect(documentRect), void 0, fitsViewport, options);
+      } finally {
+        await this._restorePageAfterScreenshot();
+      }
     });
   }
   async _preparePageForScreenshot(progress, frame, screenshotStyle, hideCaret, disableAnimations) {
     if (disableAnimations)
       progress.log("  disabled all CSS animations");
     const syncAnimations = this._page.delegate.shouldToggleStyleSheetToSyncAnimations();
-    progress.cleanupWhenAborted(() => this._restorePageAfterScreenshot());
     await progress.race(this._page.safeNonStallingEvaluateInAllFrames("(" + inPagePrepareForScreenshots.toString() + `)(${JSON.stringify(screenshotStyle)}, ${hideCaret}, ${disableAnimations}, ${syncAnimations})`, "utility"));
-    if (!process.env.PW_TEST_SCREENSHOT_NO_FONTS_READY) {
-      progress.log("waiting for fonts to load...");
-      await progress.race(frame.nonStallingEvaluateInExistingContext("document.fonts.ready", "utility").catch(() => {
-      }));
-      progress.log("fonts loaded");
+    try {
+      if (!process.env.PW_TEST_SCREENSHOT_NO_FONTS_READY) {
+        progress.log("waiting for fonts to load...");
+        await progress.race(frame.nonStallingEvaluateInExistingContext("document.fonts.ready", "utility").catch(() => {
+        }));
+        progress.log("fonts loaded");
+      }
+    } catch (error) {
+      await this._restorePageAfterScreenshot();
+      throw error;
     }
   }
   async _restorePageAfterScreenshot() {
@@ -227,39 +233,49 @@ class Screenshotter {
     if (!options.mask || !options.mask.length)
       return () => Promise.resolve();
     const framesToParsedSelectors = new import_multimap.MultiMap();
-    const cleanup = async () => {
-      await Promise.all([...framesToParsedSelectors.keys()].map(async (frame) => {
-        await frame.hideHighlight();
-      }));
-    };
-    progress.cleanupWhenAborted(cleanup);
     await progress.race(Promise.all((options.mask || []).map(async ({ frame, selector }) => {
       const pair = await frame.selectors.resolveFrameForSelector(selector);
       if (pair)
         framesToParsedSelectors.set(pair.frame, pair.info.parsed);
     })));
-    await progress.race(Promise.all([...framesToParsedSelectors.keys()].map(async (frame) => {
-      await frame.maskSelectors(framesToParsedSelectors.get(frame), options.maskColor || "#F0F");
-    })));
-    return cleanup;
+    const frames = [...framesToParsedSelectors.keys()];
+    const cleanup = async () => {
+      await Promise.all(frames.map((frame) => frame.hideHighlight()));
+    };
+    try {
+      const promises = frames.map((frame) => frame.maskSelectors(framesToParsedSelectors.get(frame), options.maskColor || "#F0F"));
+      await progress.race(Promise.all(promises));
+      return cleanup;
+    } catch (error) {
+      cleanup().catch(() => {
+      });
+      throw error;
+    }
   }
   async _screenshot(progress, format, documentRect, viewportRect, fitsViewport, options) {
     if (options.__testHookBeforeScreenshot)
       await progress.race(options.__testHookBeforeScreenshot());
     const shouldSetDefaultBackground = options.omitBackground && format === "png";
-    if (shouldSetDefaultBackground) {
-      progress.cleanupWhenAborted(() => this._page.delegate.setBackgroundColor());
-      await progress.race(this._page.delegate.setBackgroundColor({ r: 0, g: 0, b: 0, a: 0 }));
-    }
-    const cleanupHighlight = await this._maskElements(progress, options);
-    const quality = format === "jpeg" ? options.quality ?? 80 : void 0;
-    const buffer = await this._page.delegate.takeScreenshot(progress, format, documentRect, viewportRect, quality, fitsViewport, options.scale || "device");
-    await cleanupHighlight();
     if (shouldSetDefaultBackground)
-      await progress.race(this._page.delegate.setBackgroundColor());
-    if (options.__testHookAfterScreenshot)
-      await progress.race(options.__testHookAfterScreenshot());
-    return buffer;
+      await progress.race(this._page.delegate.setBackgroundColor({ r: 0, g: 0, b: 0, a: 0 }));
+    const cleanupHighlight = await this._maskElements(progress, options);
+    try {
+      const quality = format === "jpeg" ? options.quality ?? 80 : void 0;
+      const buffer = await this._page.delegate.takeScreenshot(progress, format, documentRect, viewportRect, quality, fitsViewport, options.scale || "device");
+      await cleanupHighlight();
+      if (shouldSetDefaultBackground)
+        await this._page.delegate.setBackgroundColor();
+      if (options.__testHookAfterScreenshot)
+        await progress.race(options.__testHookAfterScreenshot());
+      return buffer;
+    } catch (error) {
+      cleanupHighlight().catch(() => {
+      });
+      if (shouldSetDefaultBackground)
+        this._page.delegate.setBackgroundColor().catch(() => {
+        });
+      throw error;
+    }
   }
 }
 class TaskQueue {
