@@ -39,7 +39,8 @@ __export(utilsBundle_exports, {
   wsReceiver: () => wsReceiver,
   wsSender: () => wsSender,
   wsServer: () => wsServer,
-  yaml: () => yaml
+  yaml: () => yaml,
+  zod: () => zod
 });
 module.exports = __toCommonJS(utilsBundle_exports);
 const colors = require("./utilsBundleImpl").colors;
@@ -58,11 +59,12 @@ const program = require("./utilsBundleImpl").program;
 const ProgramOption = require("./utilsBundleImpl").ProgramOption;
 const progress = require("./utilsBundleImpl").progress;
 const SocksProxyAgent = require("./utilsBundleImpl").SocksProxyAgent;
-const yaml = require("./utilsBundleImpl").yaml;
 const ws = require("./utilsBundleImpl").ws;
 const wsServer = require("./utilsBundleImpl").wsServer;
 const wsReceiver = require("./utilsBundleImpl").wsReceiver;
 const wsSender = require("./utilsBundleImpl").wsSender;
+const yaml = require("./utilsBundleImpl").yaml;
+const zod = require("./utilsBundleImpl").zod;
 function ms(ms2) {
   if (!isFinite(ms2))
     return "-";
@@ -105,5 +107,6 @@ function ms(ms2) {
   wsReceiver,
   wsSender,
   wsServer,
-  yaml
+  yaml,
+  zod
 });
